import { __decorate, __param } from 'tslib';
import { EventEmitter, Input, Output, Component, Inject, NgModule, Optional, Injectable, SkipSelf, Pipe, ViewChild } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { MatButtonModule } from '@angular/material/button';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialogModule, MatDialog } from '@angular/material/dialog';
import { MatInputModule } from '@angular/material/input';
import { MatProgressBarModule } from '@angular/material/progress-bar';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { MatSelectModule } from '@angular/material/select';
import { MatTooltipModule } from '@angular/material/tooltip';
import { HttpClient, HttpRequest, HttpHeaders, HttpEventType, HttpResponse, HttpClientModule } from '@angular/common/http';
import { JwtHelperService } from '@auth0/angular-jwt';
import { of, Subject, forkJoin } from 'rxjs';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { MatListModule } from '@angular/material/list';
import { DomSanitizer } from '@angular/platform-browser';

var ConfirmationDialogMode;
(function (ConfirmationDialogMode) {
    ConfirmationDialogMode[ConfirmationDialogMode["OkCancel"] = 0] = "OkCancel";
    ConfirmationDialogMode[ConfirmationDialogMode["YesNo"] = 1] = "YesNo";
    ConfirmationDialogMode[ConfirmationDialogMode["TrueFalse"] = 2] = "TrueFalse";
    ConfirmationDialogMode[ConfirmationDialogMode["Custom"] = 3] = "Custom";
})(ConfirmationDialogMode || (ConfirmationDialogMode = {}));

let DialogComponent = class DialogComponent {
    constructor() {
        this.closed = new EventEmitter();
        this.ConfirmationDialogMode = ConfirmationDialogMode;
        this.mode = ConfirmationDialogMode.OkCancel;
        this.customTrueFalseText = null;
    }
    ngOnInit() {
        if (this.data) {
            this.title = this.data.title || null;
            this.message = this.data.message || null;
            this.checkboxMessage = this.data.checkboxMessage || null;
            this.placeholder = this.data.placeholder || null;
            this.userInput = this.data.value || null;
            this.mode = this.data.mode || ConfirmationDialogMode.OkCancel;
            this.customTrueFalseText = this.data.customTrueFalseText;
        }
    }
    close() {
        let data;
        switch (this.dialogType) {
            case 'message':
                data = this.checkboxMessage ?
                    {
                        checkbox: this.checkboxValue || false
                    } :
                    null;
                break;
            case 'input':
                data = this.checkboxMessage ?
                    {
                        response: this.userInput,
                        checkbox: this.checkboxValue || false
                    } :
                    this.userInput;
                break;
            case 'confirmation':
                data = this.checkboxMessage ?
                    {
                        response: true,
                        checkbox: this.checkboxValue || false
                    } :
                    true;
                break;
        }
        this.closed.emit(data);
    }
    cancel() {
        let data;
        if (this.dialogType === 'confirmation') {
            data = this.checkboxMessage ?
                {
                    response: false,
                    checkbox: this.checkboxValue || false
                } :
                false;
        }
        this.closed.emit(data);
    }
};
__decorate([
    Input()
], DialogComponent.prototype, "dialogType", void 0);
__decorate([
    Input()
], DialogComponent.prototype, "data", void 0);
__decorate([
    Output()
], DialogComponent.prototype, "closed", void 0);
DialogComponent = __decorate([
    Component({
        selector: 'cp-dialog',
        template: "<h2 *ngIf=\"title\" mat-dialog-title [innerHTML]=\"title\"></h2>\r\n\r\n<mat-dialog-content>\r\n    <div *ngIf=\"message\" [innerHTML]=\"message\"></div>\r\n\r\n    <mat-form-field *ngIf=\"dialogType === 'input'\">\r\n        <textarea matInput [placeholder]=\"placeholder\" [(ngModel)]=\"userInput\"></textarea>\r\n    </mat-form-field>\r\n\r\n    <div id=\"checkbox\" *ngIf=\"checkboxMessage\">\r\n        <mat-checkbox [(ngModel)]=\"checkboxValue\">\r\n            <span [innerHTML]=\"checkboxMessage\"></span>\r\n        </mat-checkbox>\r\n    </div>\r\n</mat-dialog-content>\r\n\r\n<mat-dialog-actions>\r\n    <button mat-raised-button (click)=\"close()\" [disabled]=\"dialogType === 'input' && !userInput\">\r\n        <span [ngSwitch]=\"mode\">\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">Yes</span>\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">True</span>\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.Custom\">{{ customTrueFalseText[0] }}</span>\r\n            <span *ngSwitchDefault>OK</span>\r\n        </span>\r\n    </button>\r\n    <button *ngIf=\"dialogType !== 'message'\" mat-raised-button (click)=\"cancel()\">\r\n        <span [ngSwitch]=\"mode\">\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">No</span>\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">False</span>\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.Custom\">{{ customTrueFalseText[1] }}</span>\r\n            <span *ngSwitchDefault>Cancel</span>\r\n        </span>\r\n    </button>\r\n</mat-dialog-actions>",
        styles: ["mat-form-field{margin-top:2em;width:100%}#checkbox{margin:2em 0}"]
    })
], DialogComponent);

let ConfirmationDialogComponent = class ConfirmationDialogComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
};
ConfirmationDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
ConfirmationDialogComponent = __decorate([
    Component({
        selector: 'cp-confirmation-dialog',
        template: "<cp-dialog\r\n  [data]=\"data\"\r\n  [dialogType]=\"'confirmation'\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog>"
    }),
    __param(1, Inject(MAT_DIALOG_DATA))
], ConfirmationDialogComponent);

let InputDialogComponent = class InputDialogComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
};
InputDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
InputDialogComponent = __decorate([
    Component({
        selector: 'cp-input-dialog',
        template: "<cp-dialog\r\n  [data]=\"data\"\r\n  [dialogType]=\"'input'\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog>"
    }),
    __param(1, Inject(MAT_DIALOG_DATA))
], InputDialogComponent);

let MessageDialogComponent = class MessageDialogComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
};
MessageDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
MessageDialogComponent = __decorate([
    Component({
        selector: 'cp-message-dialog',
        template: "<cp-dialog\r\n  [data]=\"data\"\r\n  [dialogType]=\"'message'\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog>"
    }),
    __param(1, Inject(MAT_DIALOG_DATA))
], MessageDialogComponent);

//#endregion
let DialogModule = class DialogModule {
};
DialogModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatInputModule,
            MatDialogModule
        ],
        declarations: [
            DialogComponent,
            ConfirmationDialogComponent,
            InputDialogComponent,
            MessageDialogComponent
        ],
        exports: [
            ConfirmationDialogComponent,
            InputDialogComponent,
            MessageDialogComponent
        ],
        entryComponents: [
            ConfirmationDialogComponent,
            InputDialogComponent,
            MessageDialogComponent
        ]
    })
], DialogModule);

class AuthenticationServiceConfig {
}

class SharePointServiceConfig {
}

//#endregion
let SharePointService = class SharePointService {
    //#endregion
    constructor(config, http) {
        this.config = config;
        this.http = http;
    }
    //#region Utilities
    getListItems(list) {
        return this.http.post(this.config.sharePointApiUrl, list);
    }
    getListItemsSimple(list, view, site, limit) {
        return this.http.get(`${this.config.sharePointApiUrl}/${list}/${view}/${site}/${limit}`);
    }
    getPeople(storePeople) {
        // Do we already have people stored locally?
        if (this.people) {
            return of(this.people);
            // return Observable.of(this.people);
        }
        // Should we store people locally for subsequent calls?
        if (storePeople) {
            this.http.get(`${this.config.sharePointApiUrl}/people`)
                .subscribe(peeps => this.people = peeps);
        }
        return this.http.get(`${this.config.sharePointApiUrl}/people`);
    }
    getPhotos(storePhotos) {
        // Do we already have photos stored locally?
        if (this.photos) {
            return of(this.photos);
            // return Observable.of(this.photos);
        }
        const spList = {
            list: 'Employee Thumbnail Photos',
            view: 'All Pictures',
            site: 'http://cpsp1/DigitalDisplay',
            userName: this.config.userName,
            password: this.config.password
        };
        // Should we store photos locally for subsequent calls?
        if (storePhotos) {
            this.http.post(this.config.sharePointApiUrl, spList)
                .subscribe(photos => this.photos = photos);
        }
        return this.http.post(this.config.sharePointApiUrl, spList);
    }
    getCustomerVisits() {
        const list = {
            list: 'Customer Visits',
            view: 'All Events',
            userName: this.config.userName,
            password: this.config.password
        };
        return this.http.post(this.config.sharePointApiUrl, list);
    }
};
SharePointService.ctorParameters = () => [
    { type: SharePointServiceConfig, decorators: [{ type: Optional }] },
    { type: HttpClient }
];
SharePointService = __decorate([
    Injectable(),
    __param(0, Optional())
], SharePointService);

//#endregion
/**
 * Authenticate Active Directory user
 */
let AuthenticationService = class AuthenticationService {
    //#endregion
    //#region Lifecycle
    /**
     * @ignore
     */
    constructor(config, http, sharePointService) {
        this.http = http;
        this.sharePointService = sharePointService;
        this.authenticatedChanged = new EventEmitter();
        this.authenticatingChanged = new EventEmitter();
        /**
         * Flag set to true while the service is attempting to authenticate the user
         */
        this.authenticating = false;
        /**
         * Flag set to true when the user is successfully authenticated
         */
        this.authenticated = false;
        this.authenticationApiUrl = config.authenticationApiUrl;
        this.checkForExistingToken();
    }
    //#endregion
    //#region Utilities
    /**
     * Authenticate the user and store the token in Local Storage
     *
     * @param username AD sAMAccountName
     * @param password
     * @param adminGroup AD group that determines if authenticated user is considered an administrator of the app
     */
    login(username, password, adminGroup) {
        const today = new Date();
        const expiration = new Date().setFullYear(today.getFullYear() + 10);
        const request = {
            username: username,
            password: password,
            adminGroup: adminGroup,
            expirationDate: expiration // moment().add(10, 'years').toDate()
        };
        this.authenticating = true;
        this.authenticatingChanged.emit(this.authenticating);
        this.http.post(this.authenticationApiUrl, request)
            .subscribe(token => this.validateUser(token), err => {
            this.authenticating = false;
            this.authenticatingChanged.emit(this.authenticating);
        });
    }
    /**
     * Logout the user and delete the token from Local Storage
     */
    logout() {
        if (localStorage.getItem('token')) {
            localStorage.removeItem('token');
        }
        this.authenticatedUser = null;
        this.authenticated = false;
        this.authenticatedChanged.emit(false);
    }
    /**
     * @ignore
     */
    validateUser(token) {
        if (!token) {
            return;
        }
        const jwtHelper = new JwtHelperService();
        const decoded = jwtHelper.decodeToken(token);
        if (jwtHelper.isTokenExpired(token)) {
            this.logout();
            return;
        }
        this.authenticatedUser = {
            admin: decoded.role === 'Admin',
            displayName: decoded.displayName,
            accountName: decoded.winaccountname,
            distinguishedName: decoded.distinguishedName,
            employeeNumber: decoded.employeeNumber,
            memberOf: decoded.memberOf
        };
        localStorage.setItem('token', token);
        this.getPhoto();
        this.authenticated = true;
        this.authenticatedChanged.emit(this.authenticated);
        this.authenticating = false;
        this.authenticatingChanged.emit(this.authenticating);
    }
    /**
     * @ignore
     */
    getPhoto() {
        this.sharePointService.getPhotos()
            .subscribe(photos => {
            // The user may have been logged out by the time the photos came back
            if (!this.authenticatedUser || !this.authenticatedUser.employeeNumber) {
                return;
            }
            const photo = photos.find(pic => +pic.ows_EmployeeNumber === +this.authenticatedUser.employeeNumber);
            if (photo) {
                this.authenticatedUser.photoUrl = photo.ows_EncodedAbsUrl;
            }
        });
    }
    /**
     * @ignore
     */
    checkForExistingToken() {
        if (localStorage.getItem('token')) {
            this.validateUser(localStorage.getItem('token'));
        }
    }
};
AuthenticationService.ctorParameters = () => [
    { type: AuthenticationServiceConfig, decorators: [{ type: Optional }] },
    { type: HttpClient },
    { type: SharePointService }
];
__decorate([
    Output()
], AuthenticationService.prototype, "authenticatedChanged", void 0);
__decorate([
    Output()
], AuthenticationService.prototype, "authenticatingChanged", void 0);
AuthenticationService = __decorate([
    Injectable(),
    __param(0, Optional())
], AuthenticationService);

let LoginFormComponent = class LoginFormComponent {
    constructor(dialogRef, sharePointService, authenticationService, data) {
        this.dialogRef = dialogRef;
        this.sharePointService = sharePointService;
        this.authenticationService = authenticationService;
        this.data = data;
        this.adminGroup = data.adminGroup;
    }
    ngOnInit() {
        this.authenticationService.authenticatedChanged
            .subscribe(authenticated => {
            if (authenticated) {
                this.dialogRef.close();
            }
        });
    }
    authenticate() {
        if (!this.sharePointService || !this.username || !this.password) {
            return;
        }
        this.authenticationService.login(this.username, this.password, this.adminGroup);
    }
};
LoginFormComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: SharePointService },
    { type: AuthenticationService },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
LoginFormComponent = __decorate([
    Component({
        selector: 'cp-login-form',
        template: "<h2 mat-dialog-title>\n  <span *ngIf=\"!authenticationService.authenticating\">Login</span>\n  <span *ngIf=\"authenticationService.authenticating\">Authenticating...</span>\n</h2>\n\n<mat-dialog-content [class.loginError]=\"loginError\">\n  <div id=\"spinner\" *ngIf=\"authenticationService.authenticating\">\n    <mat-progress-spinner color=\"primary\" mode=\"indeterminate\"></mat-progress-spinner>\n  </div>\n\n  <div *ngIf=\"!authenticationService.authenticating\">\n    <div>\n      <mat-form-field>\n        <input matInput placeholder=\"Username\" [(ngModel)]=\"username\" name=\"username\" required (keyup.enter)=\"authenticate()\">\n      </mat-form-field>\n    </div>\n\n    <div>\n      <mat-form-field>\n        <input matInput type=\"password\" placeholder=\"Password\" [(ngModel)]=\"password\" name=\"password\" required (keyup.enter)=\"authenticate()\">\n      </mat-form-field>\n    </div>\n  </div>\n\n  <div *ngIf=\"!authenticationService.authenticating && loginError\" class=\"alert alert-danger\">\n    Bad username or password\n  </div>\n</mat-dialog-content>\n\n<mat-dialog-actions *ngIf=\"!authenticationService.authenticating\">\n  <button type=\"button\" mat-raised-button (click)=\"authenticate()\">OK</button>\n  <button type=\"button\" mat-button (click)=\"dialogRef.close()\">Cancel</button>\n</mat-dialog-actions>",
        styles: ["#spinner{width:100%;height:100%;display:flex;justify-content:center;align-items:center}mat-dialog-content{height:150px}mat-dialog-content.loginError{height:200px}"]
    }),
    __param(3, Inject(MAT_DIALOG_DATA))
], LoginFormComponent);

let LoginComponent = class LoginComponent {
    constructor(dialog, authenticationService) {
        this.dialog = dialog;
        this.authenticationService = authenticationService;
    }
    ngOnInit() {
    }
    login() {
        this.dialog.open(LoginFormComponent, {
            data: { adminGroup: this.adminGroup }
        });
    }
    confirmLogout() {
        const dialogRef = this.dialog.open(ConfirmationDialogComponent, {
            data: { message: `Are you sure you want to logout?` }
        });
        dialogRef.afterClosed().subscribe(result => {
            if (result) {
                this.authenticationService.logout();
            }
        });
    }
};
LoginComponent.ctorParameters = () => [
    { type: MatDialog },
    { type: AuthenticationService }
];
__decorate([
    Input()
], LoginComponent.prototype, "adminGroup", void 0);
LoginComponent = __decorate([
    Component({
        selector: 'cp-login',
        template: "<div id=\"user-id\">\n  <i id=\"unauthenticated-user-image\" *ngIf=\"!authenticationService.authenticated\"\n    class=\"fa fa-user-circle\"\n    [class.fa-spin]=\"authenticationService.authenticating\"\n    aria-hidden=\"true\"\n    matTooltip=\"Login\"\n    (click)=\"login()\"></i>\n\n  <img id=\"authenticated-user-image\"\n    *ngIf=\"authenticationService.authenticated && authenticationService.authenticatedUser.photoUrl\"\n    [src]=\"authenticationService.authenticatedUser.photoUrl\"\n    matTooltip=\"Logout\"\n    (click)=\"confirmLogout()\" />\n\n  <i id=\"authenticated-user-image\"\n    *ngIf=\"authenticationService.authenticated && !authenticationService.authenticatedUser.photoUrl\"\n    class=\"fa fa-user-circle\"\n    matTooltip=\"Logout\"\n    (click)=\"confirmLogout()\"></i>\n\n  <div id=\"user-name\" *ngIf=\"authenticationService.authenticated\">\n    {{ authenticationService.authenticatedUser.displayName }}\n  </div>\n</div>",
        styles: ["#user-id{display:flex;height:2em;padding:.3em;font-family:Verdana,Geneva,Tahoma,sans-serif}.fa{font-size:2em}img{border-radius:100%;width:2em;height:2em}#user-id>div{display:flex;align-items:center;height:100%;margin-left:.75em;font-size:1.15em}"]
    })
], LoginComponent);

var AuthenticationModule_1;
//#endregion
/**
 * Provides a component and a service that allows you to perform Active/Directory authentication
 */
let AuthenticationModule = AuthenticationModule_1 = class AuthenticationModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('AuthenticationModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(authenticationConfig) {
        return {
            ngModule: AuthenticationModule_1,
            providers: [
                AuthenticationService,
                { provide: AuthenticationServiceConfig, useValue: authenticationConfig }
            ]
        };
    }
};
AuthenticationModule.ctorParameters = () => [
    { type: AuthenticationModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];
AuthenticationModule = AuthenticationModule_1 = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatDialogModule,
            MatInputModule,
            MatProgressBarModule,
            MatProgressSpinnerModule,
            MatTooltipModule,
            MatSelectModule,
            DialogModule
        ],
        declarations: [
            LoginComponent,
            LoginFormComponent
        ],
        exports: [
            LoginComponent,
            LoginFormComponent
        ],
        providers: [],
        entryComponents: [
            LoginFormComponent
        ]
    }),
    __param(0, Optional()), __param(0, SkipSelf())
], AuthenticationModule);

class EmailServiceConfig {
}

//#endregion
let EmailService = class EmailService {
    constructor(config, http) {
        this.http = http;
        this.emailServiceConfig = config;
    }
    send(email) {
        const dto = {
            server: this.emailServiceConfig.server,
            smtpPort: this.emailServiceConfig.smtpPort,
            sender: this.emailServiceConfig.sender,
            subject: email.subject,
            content: email.content,
            recipients: email.recipients
        };
        return this.http.post(this.emailServiceConfig.emailApiUrl, dto);
    }
};
EmailService.ctorParameters = () => [
    { type: EmailServiceConfig, decorators: [{ type: Optional }] },
    { type: HttpClient }
];
EmailService = __decorate([
    Injectable(),
    __param(0, Optional())
], EmailService);

var EmailModule_1;
//#endregion
let EmailModule = EmailModule_1 = class EmailModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('EmailModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(emailConfig) {
        return {
            ngModule: EmailModule_1,
            providers: [
                EmailService,
                { provide: EmailServiceConfig, useValue: emailConfig }
            ]
        };
    }
};
EmailModule.ctorParameters = () => [
    { type: EmailModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];
EmailModule = EmailModule_1 = __decorate([
    NgModule({
        imports: [CommonModule],
        declarations: [],
        exports: []
    }),
    __param(0, Optional()), __param(0, SkipSelf())
], EmailModule);

class EmployeeServiceConfig {
}

//#endregion
let EmployeeService = class EmployeeService {
    //#endregion
    //#region Lifecycle
    constructor(config, http) {
        this.http = http;
        this.employeeApiUrl = config.employeeApiUrl;
    }
    //#endregion
    //#region Utilities
    getEmployees(storeEmployees = false, includeDisabled = false) {
        // Do we already have employees stored locally?
        if (this.employees) {
            return of(this.employees);
            // return Observable.of(this.employees);
        }
        // Should we store employees locally for subsequent calls?
        if (storeEmployees) {
            this.http.get(`${this.employeeApiUrl}/false/${includeDisabled}`)
                .subscribe(emps => this.employees = emps);
        }
        return this.http.get(`${this.employeeApiUrl}/false/${includeDisabled}`);
    }
    getEmployee(sAMAccountName) {
        return this.http.get(`${this.employeeApiUrl}/name/${sAMAccountName}`);
    }
};
EmployeeService.ctorParameters = () => [
    { type: EmployeeServiceConfig, decorators: [{ type: Optional }] },
    { type: HttpClient }
];
EmployeeService = __decorate([
    Injectable(),
    __param(0, Optional())
], EmployeeService);

let DepartmentsPipe = class DepartmentsPipe {
    transform(employees, args) {
        const departments = [];
        employees
            .filter(emp => emp.department)
            .forEach(emp => {
            if (departments.indexOf(emp.department) === -1) {
                departments.push(emp.department);
            }
        });
        return departments.sort();
    }
};
DepartmentsPipe = __decorate([
    Pipe({
        name: 'departments'
    })
], DepartmentsPipe);

let EmployeeByDnPipe = class EmployeeByDnPipe {
    transform(employees, dn) {
        return employees
            .find(emp => emp.distinguishedName.toLowerCase() === dn.toLowerCase());
    }
};
EmployeeByDnPipe = __decorate([
    Pipe({
        name: 'employeeByDn'
    })
], EmployeeByDnPipe);

let EmployeePhotoUrlPipe = class EmployeePhotoUrlPipe {
    transform(employee, photos) {
        if (!photos) {
            return null;
        }
        // Try to match by employeeNumber, accountName, or title
        const photo = photos
            .find(pic => (pic.ows_EmployeeNumber && employee.employeeNumber && +pic.ows_EmployeeNumber === +employee.employeeNumber) ||
            (pic.ows_AccountName && pic.ows_AccountName.toLowerCase() === employee.sAMAccountName.toLowerCase()) ||
            (pic.ows_Title && pic.ows_Title.toLowerCase() === employee.displayName.toLowerCase()));
        if (!photo) {
            console.log(`No photo match for ${employee.displayName}`);
        }
        return photo ? photo.ows_EncodedAbsUrl : null;
    }
};
EmployeePhotoUrlPipe = __decorate([
    Pipe({
        name: 'employeePhotoUrl'
    })
], EmployeePhotoUrlPipe);

let EmployeesWithPropertyValuePipe = class EmployeesWithPropertyValuePipe {
    transform(employees, propertyName, propertyValue) {
        return employees
            .filter(emp => emp[propertyName] && emp[propertyName] === propertyValue);
    }
};
EmployeesWithPropertyValuePipe = __decorate([
    Pipe({
        name: 'employeesWithPropertyValue'
    })
], EmployeesWithPropertyValuePipe);

let FilterEmployeesPipe = class FilterEmployeesPipe {
    transform(employees, filter) {
        return filter ?
            employees
                .filter(emp => emp.displayName.toLowerCase().indexOf(filter.toLowerCase()) !== -1 ||
                (emp.department && emp.department.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                (emp.title && emp.title.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                emp.sAMAccountName.toLowerCase().indexOf(filter.toLowerCase()) !== -1) :
            employees;
    }
};
FilterEmployeesPipe = __decorate([
    Pipe({
        name: 'filterEmployees'
    })
], FilterEmployeesPipe);

let IsMemberOfPipe = class IsMemberOfPipe {
    transform(employee, groupName) {
        return employee.memberOf &&
            (employee.memberOf.find(m => m.toLowerCase().indexOf(groupName.toLowerCase()) !== -1) !== undefined);
    }
};
IsMemberOfPipe = __decorate([
    Pipe({
        name: 'isMemberOf'
    })
], IsMemberOfPipe);

let SortEmployeesPipe = class SortEmployeesPipe {
    transform(employees, sortBy, dataType, reverse) {
        return this.getSorted(employees, sortBy ? sortBy : 'displayName', dataType ? dataType : 'string', reverse ? reverse : false);
    }
    getSorted(employees, sortBy, dataType, reverse) {
        const sorted = employees
            .sort((a, b) => {
            let valA, valB;
            switch (dataType.toLowerCase()) {
                case 'string':
                    valA = a[sortBy] ? a[sortBy].toString().toLowerCase() : null;
                    valB = b[sortBy] ? b[sortBy].toString().toLowerCase() : null;
                    break;
                case 'number':
                    valA = a[sortBy] ? +a[sortBy] : null;
                    valB = b[sortBy] ? +b[sortBy] : null;
                    break;
                case 'date':
                    valA = a[sortBy] ? a[sortBy] : null;
                    valB = b[sortBy] ? b[sortBy] : null;
                    break;
            }
            if (valA < valB) {
                return -1;
            }
            if (valA > valB) {
                return 1;
            }
            return 0;
        });
        return reverse ? sorted.reverse() : sorted;
    }
};
SortEmployeesPipe = __decorate([
    Pipe({
        name: 'sortEmployees'
    })
], SortEmployeesPipe);

var EmployeeModule_1;
//#endregion
let EmployeeModule = EmployeeModule_1 = class EmployeeModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('EmployeeModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(employeeConfig) {
        return {
            ngModule: EmployeeModule_1,
            providers: [
                EmployeeService,
                { provide: EmployeeServiceConfig, useValue: employeeConfig }
            ]
        };
    }
};
EmployeeModule.ctorParameters = () => [
    { type: EmployeeModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];
EmployeeModule = EmployeeModule_1 = __decorate([
    NgModule({
        imports: [CommonModule],
        declarations: [
            DepartmentsPipe,
            EmployeeByDnPipe,
            EmployeesWithPropertyValuePipe,
            FilterEmployeesPipe,
            IsMemberOfPipe,
            EmployeePhotoUrlPipe,
            SortEmployeesPipe
        ],
        exports: [
            DepartmentsPipe,
            EmployeeByDnPipe,
            EmployeesWithPropertyValuePipe,
            FilterEmployeesPipe,
            IsMemberOfPipe,
            EmployeePhotoUrlPipe,
            SortEmployeesPipe
        ]
    }),
    __param(0, Optional()), __param(0, SkipSelf())
], EmployeeModule);

let SharePointPhotoUrlPipe = class SharePointPhotoUrlPipe {
    transform(photo) {
        return photo.ows_EncodedAbsUrl;
    }
};
SharePointPhotoUrlPipe = __decorate([
    Pipe({
        name: 'sharePointPhotoUrl'
    })
], SharePointPhotoUrlPipe);

let SharePointUrlPipe = class SharePointUrlPipe {
    transform(url) {
        return url !== null ? url.split(',')[0] : null;
    }
};
SharePointUrlPipe = __decorate([
    Pipe({
        name: 'sharePointUrl'
    })
], SharePointUrlPipe);

var SharePointModule_1;
//#endregion
let SharePointModule = SharePointModule_1 = class SharePointModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('SharePointModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(sharePointConfig) {
        return {
            ngModule: SharePointModule_1,
            providers: [
                SharePointService,
                { provide: SharePointServiceConfig, useValue: sharePointConfig }
            ]
        };
    }
};
SharePointModule.ctorParameters = () => [
    { type: SharePointModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];
SharePointModule = SharePointModule_1 = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [
            SharePointPhotoUrlPipe,
            SharePointUrlPipe
        ],
        exports: [
            SharePointPhotoUrlPipe,
            SharePointUrlPipe
        ]
    }),
    __param(0, Optional()), __param(0, SkipSelf())
], SharePointModule);

class UploadServiceConfig {
}

// https://malcoded.com/posts/angular-file-upload-component-with-express
let UploadService = class UploadService {
    constructor(http, config) {
        this.http = http;
        this.uploadApiUrl = config.uploadApiUrl;
        this.uploadPath = config.uploadPath || '';
        this.dbAppId = config.dbAppId || '';
        this.externalReferenceId = config.externalReferenceId || '';
        this.comment = config.comment || '';
        // UI configuration
        this.uploadButtonText = config.uploadButtonText;
        this.uploadDialogTitle = config.uploadDialogTitle;
        this.uploadDialogAddFilesButtonText = config.uploadDialogAddFilesButtonText;
        this.uploadDialogCancelButtonText = config.uploadDialogCancelButtonText;
        this.uploadDialogUploadButtonText = config.uploadDialogUploadButtonText;
        this.uploadDialogFinishButtonText = config.uploadDialogFinishButtonText;
    }
    upload(files) {
        // this will be the our resulting map
        const status = {};
        files.forEach(file => {
            // create a new multipart-form for every file
            const formData = new FormData();
            formData.append('file', file, file.name);
            // create a http-post request and pass the form
            // tell it to report the upload progress
            // A 'Destination' header is used to optionally configure the file upload destination (filesystem)
            // A 'DbAppId' header is used to configure the unique identifier of database uploads
            const req = new HttpRequest('POST', this.uploadApiUrl, formData, {
                reportProgress: true,
                responseType: 'blob',
                headers: new HttpHeaders()
                    .set('Destination', this.uploadPath)
                    .set('DbAppId', this.dbAppId)
                    .set('ExternalReferenceId', this.externalReferenceId)
                    .set('Comment', this.comment)
                /*headers: this.uploadPath ?
                  new HttpHeaders({ 'Destination': this.uploadPath }) :
                  this.dbAppId ?
                    new HttpHeaders({ 'DbAppId': this.dbAppId }) :
                    null*/
            });
            // create a new progress-subject for every file
            const progress = new Subject();
            // send the http-request and subscribe for progress-updates
            this.http.request(req).subscribe(event => {
                if (event.type === HttpEventType.UploadProgress) {
                    // calculate the progress percentage
                    const percentDone = Math.round(100 * event.loaded / event.total);
                    // pass the percentage into the progress-stream
                    progress.next(percentDone);
                }
                else if (event instanceof HttpResponse) {
                    // Close the progress-stream if we get an answer form the API
                    // The upload is complete
                    progress.complete();
                }
            });
            // Save every progress-observable in a map of all observables
            status[file.name] = {
                progress: progress.asObservable()
            };
        });
        // return the map of progress.observables
        return status;
    }
    exists(fileName) {
        const query = this.uploadApiUrl.toLowerCase().indexOf('filesystem') === -1 ?
            { name: fileName, dbAppId: this.dbAppId } :
            { name: fileName, destination: this.uploadPath };
        return this.http.post(`${this.uploadApiUrl}/exists`, query);
    }
    download(request) {
        return this.http.post(`${this.uploadApiUrl}/stream`, request, { responseType: 'blob' });
    }
    getUploadInfo(request) {
        return this.http.post(`${this.uploadApiUrl}/info`, request);
    }
};
UploadService.ctorParameters = () => [
    { type: HttpClient },
    { type: UploadServiceConfig, decorators: [{ type: Optional }] }
];
UploadService = __decorate([
    Injectable(),
    __param(1, Optional())
], UploadService);

let UploadDialogComponent = class UploadDialogComponent {
    constructor(dialogRef, uploadService) {
        this.dialogRef = dialogRef;
        this.uploadService = uploadService;
        this.files = new Set();
        this.canBeClosed = true;
        this.showCancelButton = true;
        this.uploading = false;
        this.uploadSuccessful = false;
    }
    ngOnInit() {
        this.uploadDialogTitle = this.uploadService.uploadDialogTitle ?
            this.uploadService.uploadDialogTitle :
            'Upload Files';
        this.uploadDialogAddFilesButtonText = this.uploadService.uploadDialogAddFilesButtonText ?
            this.uploadService.uploadDialogAddFilesButtonText :
            'Add Files';
        this.uploadDialogCancelButtonText = this.uploadService.uploadDialogCancelButtonText ?
            this.uploadService.uploadDialogCancelButtonText :
            'Cancel';
        this.uploadDialogUploadButtonText = this.uploadService.uploadDialogUploadButtonText ?
            this.uploadService.uploadDialogUploadButtonText :
            'Upload';
        this.uploadDialogFinishButtonText = this.uploadService.uploadDialogFinishButtonText ?
            this.uploadService.uploadDialogFinishButtonText :
            'Finish';
        this.primaryButtonText = this.uploadDialogUploadButtonText;
    }
    addFiles() {
        this.file.nativeElement.click();
    }
    onFilesAdded() {
        const files = this.file.nativeElement.files;
        for (const key in files) {
            if (!isNaN(parseInt(key))) {
                // See if the file already exists
                this.uploadService.exists(files[key].name)
                    .subscribe(exists => {
                    if (exists) {
                        this.existingFileConflict = files[key].name;
                    }
                    if (!exists) {
                        this.files.add(files[key]);
                    }
                });
            }
        }
    }
    closeDialog() {
        // if everything was uploaded already, just close the dialog
        if (this.uploadSuccessful) {
            return this.dialogRef.close();
        }
        // set the component state to "uploading"
        this.uploading = true;
        // start the upload and save the progress map
        this.progress = this.uploadService.upload(this.files);
        // convert the progress map into an array
        const allProgressObservables = [];
        for (let key in this.progress) {
            allProgressObservables.push(this.progress[key].progress);
        }
        // Adjust the state variables
        // The OK-button should have the text "Finish" now
        this.primaryButtonText = this.uploadDialogFinishButtonText;
        // The dialog should not be closed while uploading
        this.canBeClosed = false;
        this.dialogRef.disableClose = true;
        // Hide the cancel-button
        this.showCancelButton = false;
        // When all progress-observables are completed...
        forkJoin(allProgressObservables).subscribe(end => {
            // ... the dialog can be closed again...
            this.canBeClosed = true;
            this.dialogRef.disableClose = false;
            // ... the upload was successful...
            this.uploadSuccessful = true;
            // ... and the component is no longer uploading
            this.uploading = false;
        });
    }
};
UploadDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: UploadService }
];
__decorate([
    ViewChild('file', { static: true })
], UploadDialogComponent.prototype, "file", void 0);
UploadDialogComponent = __decorate([
    Component({
        selector: 'cp-upload-dialog',
        template: "<input type=\"file\" #file style=\"display: none\" (change)=\"onFilesAdded()\" multiple />\r\n\r\n<div mat-dialog-title id=\"title\">\r\n  <div>{{ uploadDialogTitle }}</div>\r\n  <button [disabled]=\"uploading || uploadSuccessful\" mat-raised-button color=\"primary\" class=\"add-files-btn\" (click)=\"addFiles()\">\r\n    {{ uploadDialogAddFilesButtonText }}\r\n  </button>\r\n</div>\r\n\r\n<div id=\"conflict\" *ngIf=\"existingFileConflict\">\r\n  {{ existingFileConflict }} already exists on the server and cannot be overwritten\r\n</div>\r\n\r\n<mat-dialog-content>\r\n  <mat-list>\r\n    <mat-list-item *ngFor=\"let file of files\">\r\n      <h4 mat-line>{{file.name}}</h4>\r\n      <mat-progress-bar *ngIf=\"progress\" mode=\"determinate\" [value]=\"progress[file.name].progress | async\"></mat-progress-bar>\r\n    </mat-list-item>\r\n  </mat-list>\r\n</mat-dialog-content>\r\n\r\n<mat-dialog-actions id=\"actions\">\r\n  <button *ngIf=\"showCancelButton\" mat-button mat-dialog-close>{{ uploadDialogCancelButtonText }}</button>\r\n  <button *ngIf=\"files.size > 0\" mat-raised-button color=\"primary\" [disabled]=\"!canBeClosed\" (click)=\"closeDialog()\">{{ primaryButtonText }}</button>\r\n</mat-dialog-actions>\r\n",
        styles: ["#title{display:flex;justify-content:space-between}#actions{display:flex;justify-content:flex-end}#conflict{font-size:.8em;color:red;margin-top:.5em}"]
    })
], UploadDialogComponent);

let UploadComponent = class UploadComponent {
    constructor(dialog, uploadService) {
        this.dialog = dialog;
        this.uploadService = uploadService;
        this.dialogClosed = new EventEmitter();
    }
    ngOnInit() {
        this.uploadButtonText = this.uploadService.uploadButtonText ?
            this.uploadService.uploadButtonText :
            'Upload';
    }
    openUploadDialog() {
        this.dialog.open(UploadDialogComponent, { width: '50%' })
            .afterClosed().subscribe(() => this.dialogClosed.emit());
    }
};
UploadComponent.ctorParameters = () => [
    { type: MatDialog },
    { type: UploadService }
];
__decorate([
    Output()
], UploadComponent.prototype, "dialogClosed", void 0);
UploadComponent = __decorate([
    Component({
        selector: 'cp-upload',
        template: '<button mat-raised-button (click)="openUploadDialog()">{{ uploadButtonText }}</button>'
    })
], UploadComponent);

var UploadModule_1;
//#endregion
let UploadModule = UploadModule_1 = class UploadModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('UploadModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(uploadConfig) {
        return {
            ngModule: UploadModule_1,
            providers: [
                UploadService,
                { provide: UploadServiceConfig, useValue: uploadConfig }
            ]
        };
    }
};
UploadModule.ctorParameters = () => [
    { type: UploadModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];
UploadModule = UploadModule_1 = __decorate([
    NgModule({
        imports: [
            CommonModule,
            BrowserAnimationsModule,
            HttpClientModule,
            MatButtonModule,
            MatDialogModule,
            MatListModule,
            MatProgressBarModule
        ],
        declarations: [
            UploadComponent,
            UploadDialogComponent
        ],
        exports: [
            UploadComponent,
            UploadDialogComponent
        ],
        entryComponents: [
            UploadDialogComponent
        ]
    }),
    __param(0, Optional()), __param(0, SkipSelf())
], UploadModule);

// This pipe whitelists URLs so that they aren't prefixed with 'unsafe:' when they render in the DOM
let SafeUrlPipe = class SafeUrlPipe {
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    transform(value) {
        return this.domSanitizer.bypassSecurityTrustUrl(value);
    }
};
SafeUrlPipe.ctorParameters = () => [
    { type: DomSanitizer }
];
SafeUrlPipe = __decorate([
    Pipe({
        name: 'safeUrl'
    })
], SafeUrlPipe);

let UriSchemePipe = class UriSchemePipe {
    // https://docs.microsoft.com/en-us/office/client-developer/office-uri-schemes
    transform(value) {
        if (!localStorage.getItem('useUriScheme')) {
            return value;
        }
        const urlSplit = value.split('.');
        const extension = urlSplit[urlSplit.length - 1];
        if (!extension) {
            return value;
        }
        const command = this.command(extension);
        const app = this.app(extension);
        return `ms-${app}:${command}|u|${value}`;
    }
    app(extension) {
        switch (extension.toLowerCase()) {
            // documents
            case 'doc':
            case 'docx':
            case 'docm':
            case 'docb':
            case 'dot':
            case 'dotx':
            case 'dotm': // templates
                return 'word';
            case 'xls':
            case 'xlsx':
            case 'xlm':
            case 'xlsm':
            case 'xlsb':
            case 'xlw':
            case 'xlt':
            case 'xltx':
            case 'xltm': // templates
                return 'excel';
            case 'ppt':
            case 'pptx':
            case 'pps':
            case 'ppsx':
            case 'pptm':
            case 'ppsm':
            case 'sldx':
            case 'sldm':
            case 'pot':
            case 'potx':
            case 'potm': // templates
                return 'powerpoint';
            case 'vsd':
            case 'vsdx':
            case 'vst':
            case 'vstx': // templates
                return 'visio';
            case 'mdb':
            case 'accdb':
            case 'accde':
            case 'accdr':
            case 'accdt': // templates
                return 'access';
            case 'mpp':
            case 'mppx':
            case 'mpt': // templates
                return 'project';
            case 'pub':
                return 'publisher';
            case 'xsn':
                return 'infopath';
        }
    }
    command(extension) {
        switch (extension.toLowerCase()) {
            case 'dot':
            case 'dotx':
            case 'dotm':
            case 'xlt':
            case 'xltx':
            case 'xltm':
            case 'pot':
            case 'potx':
            case 'potm':
            case 'vst':
            case 'vstx':
            case 'accdt':
            case 'mpt':
                return 'nft'; // new from template
            default:
                const openMode = 'v'; // for view, or 'e' or edit
                return `of${openMode}`; // default: open file as view/edit
        }
    }
};
UriSchemePipe = __decorate([
    Pipe({
        name: 'uriScheme',
        pure: false
    })
], UriSchemePipe);

//#endregion
let UrlModule = class UrlModule {
};
UrlModule = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [
            SafeUrlPipe,
            UriSchemePipe
        ],
        exports: [
            SafeUrlPipe,
            UriSchemePipe
        ],
        entryComponents: []
    })
], UrlModule);

/**
 * Generated bundle index. Do not edit.
 */

export { AuthenticationModule, AuthenticationService, AuthenticationServiceConfig, ConfirmationDialogComponent, ConfirmationDialogMode, DepartmentsPipe, DialogModule, EmailModule, EmailService, EmailServiceConfig, EmployeeByDnPipe, EmployeeModule, EmployeePhotoUrlPipe, EmployeeService, EmployeeServiceConfig, EmployeesWithPropertyValuePipe, FilterEmployeesPipe, InputDialogComponent, IsMemberOfPipe, LoginComponent, LoginFormComponent, MessageDialogComponent, SafeUrlPipe, SharePointModule, SharePointPhotoUrlPipe, SharePointService, SharePointServiceConfig, SharePointUrlPipe, SortEmployeesPipe, UploadComponent, UploadDialogComponent, UploadModule, UploadService, UploadServiceConfig, UriSchemePipe, UrlModule, DialogComponent as ɵa };
//# sourceMappingURL=cleavelandprice-ngx-lib.js.map
