import { __decorate, __param } from 'tslib';
import { EventEmitter, Input, Output, Component, Inject, NgModule, Optional, Injectable, SkipSelf, Pipe, ViewChild } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { MatButtonModule } from '@angular/material/button';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialogModule, MatDialog } from '@angular/material/dialog';
import { MatInputModule } from '@angular/material/input';
import { MatProgressBarModule } from '@angular/material/progress-bar';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { MatSelectModule } from '@angular/material/select';
import { MatTooltipModule } from '@angular/material/tooltip';
import { HttpClient, HttpRequest, HttpHeaders, HttpEventType, HttpResponse, HttpClientModule } from '@angular/common/http';
import { JwtHelperService } from '@auth0/angular-jwt';
import { of, Subject, forkJoin } from 'rxjs';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { MatListModule } from '@angular/material/list';
import { DomSanitizer } from '@angular/platform-browser';

var ConfirmationDialogMode;
(function (ConfirmationDialogMode) {
    ConfirmationDialogMode[ConfirmationDialogMode["OkCancel"] = 0] = "OkCancel";
    ConfirmationDialogMode[ConfirmationDialogMode["YesNo"] = 1] = "YesNo";
    ConfirmationDialogMode[ConfirmationDialogMode["TrueFalse"] = 2] = "TrueFalse";
    ConfirmationDialogMode[ConfirmationDialogMode["Custom"] = 3] = "Custom";
})(ConfirmationDialogMode || (ConfirmationDialogMode = {}));

var DialogComponent = /** @class */ (function () {
    function DialogComponent() {
        this.closed = new EventEmitter();
        this.ConfirmationDialogMode = ConfirmationDialogMode;
        this.mode = ConfirmationDialogMode.OkCancel;
        this.customTrueFalseText = null;
    }
    DialogComponent.prototype.ngOnInit = function () {
        if (this.data) {
            this.title = this.data.title || null;
            this.message = this.data.message || null;
            this.checkboxMessage = this.data.checkboxMessage || null;
            this.placeholder = this.data.placeholder || null;
            this.userInput = this.data.value || null;
            this.mode = this.data.mode || ConfirmationDialogMode.OkCancel;
            this.customTrueFalseText = this.data.customTrueFalseText;
        }
    };
    DialogComponent.prototype.close = function () {
        var data;
        switch (this.dialogType) {
            case 'message':
                data = this.checkboxMessage ?
                    {
                        checkbox: this.checkboxValue || false
                    } :
                    null;
                break;
            case 'input':
                data = this.checkboxMessage ?
                    {
                        response: this.userInput,
                        checkbox: this.checkboxValue || false
                    } :
                    this.userInput;
                break;
            case 'confirmation':
                data = this.checkboxMessage ?
                    {
                        response: true,
                        checkbox: this.checkboxValue || false
                    } :
                    true;
                break;
        }
        this.closed.emit(data);
    };
    DialogComponent.prototype.cancel = function () {
        var data;
        if (this.dialogType === 'confirmation') {
            data = this.checkboxMessage ?
                {
                    response: false,
                    checkbox: this.checkboxValue || false
                } :
                false;
        }
        this.closed.emit(data);
    };
    __decorate([
        Input()
    ], DialogComponent.prototype, "dialogType", void 0);
    __decorate([
        Input()
    ], DialogComponent.prototype, "data", void 0);
    __decorate([
        Output()
    ], DialogComponent.prototype, "closed", void 0);
    DialogComponent = __decorate([
        Component({
            selector: 'cp-dialog',
            template: "<h2 *ngIf=\"title\" mat-dialog-title [innerHTML]=\"title\"></h2>\r\n\r\n<mat-dialog-content>\r\n    <div *ngIf=\"message\" [innerHTML]=\"message\"></div>\r\n\r\n    <mat-form-field *ngIf=\"dialogType === 'input'\">\r\n        <textarea matInput [placeholder]=\"placeholder\" [(ngModel)]=\"userInput\"></textarea>\r\n    </mat-form-field>\r\n\r\n    <div id=\"checkbox\" *ngIf=\"checkboxMessage\">\r\n        <mat-checkbox [(ngModel)]=\"checkboxValue\">\r\n            <span [innerHTML]=\"checkboxMessage\"></span>\r\n        </mat-checkbox>\r\n    </div>\r\n</mat-dialog-content>\r\n\r\n<mat-dialog-actions>\r\n    <button mat-raised-button (click)=\"close()\" [disabled]=\"dialogType === 'input' && !userInput\">\r\n        <span [ngSwitch]=\"mode\">\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">Yes</span>\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">True</span>\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.Custom\">{{ customTrueFalseText[0] }}</span>\r\n            <span *ngSwitchDefault>OK</span>\r\n        </span>\r\n    </button>\r\n    <button *ngIf=\"dialogType !== 'message'\" mat-raised-button (click)=\"cancel()\">\r\n        <span [ngSwitch]=\"mode\">\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">No</span>\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">False</span>\r\n            <span *ngSwitchCase=\"ConfirmationDialogMode.Custom\">{{ customTrueFalseText[1] }}</span>\r\n            <span *ngSwitchDefault>Cancel</span>\r\n        </span>\r\n    </button>\r\n</mat-dialog-actions>",
            styles: ["mat-form-field{margin-top:2em;width:100%}#checkbox{margin:2em 0}"]
        })
    ], DialogComponent);
    return DialogComponent;
}());

var ConfirmationDialogComponent = /** @class */ (function () {
    function ConfirmationDialogComponent(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    ConfirmationDialogComponent.ctorParameters = function () { return [
        { type: MatDialogRef },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
    ]; };
    ConfirmationDialogComponent = __decorate([
        Component({
            selector: 'cp-confirmation-dialog',
            template: "<cp-dialog\r\n  [data]=\"data\"\r\n  [dialogType]=\"'confirmation'\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog>"
        }),
        __param(1, Inject(MAT_DIALOG_DATA))
    ], ConfirmationDialogComponent);
    return ConfirmationDialogComponent;
}());

var InputDialogComponent = /** @class */ (function () {
    function InputDialogComponent(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    InputDialogComponent.ctorParameters = function () { return [
        { type: MatDialogRef },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
    ]; };
    InputDialogComponent = __decorate([
        Component({
            selector: 'cp-input-dialog',
            template: "<cp-dialog\r\n  [data]=\"data\"\r\n  [dialogType]=\"'input'\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog>"
        }),
        __param(1, Inject(MAT_DIALOG_DATA))
    ], InputDialogComponent);
    return InputDialogComponent;
}());

var MessageDialogComponent = /** @class */ (function () {
    function MessageDialogComponent(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    MessageDialogComponent.ctorParameters = function () { return [
        { type: MatDialogRef },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
    ]; };
    MessageDialogComponent = __decorate([
        Component({
            selector: 'cp-message-dialog',
            template: "<cp-dialog\r\n  [data]=\"data\"\r\n  [dialogType]=\"'message'\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog>"
        }),
        __param(1, Inject(MAT_DIALOG_DATA))
    ], MessageDialogComponent);
    return MessageDialogComponent;
}());

//#endregion
var DialogModule = /** @class */ (function () {
    function DialogModule() {
    }
    DialogModule = __decorate([
        NgModule({
            imports: [
                CommonModule,
                FormsModule,
                MatButtonModule,
                MatCheckboxModule,
                MatInputModule,
                MatDialogModule
            ],
            declarations: [
                DialogComponent,
                ConfirmationDialogComponent,
                InputDialogComponent,
                MessageDialogComponent
            ],
            exports: [
                ConfirmationDialogComponent,
                InputDialogComponent,
                MessageDialogComponent
            ],
            entryComponents: [
                ConfirmationDialogComponent,
                InputDialogComponent,
                MessageDialogComponent
            ]
        })
    ], DialogModule);
    return DialogModule;
}());

var AuthenticationServiceConfig = /** @class */ (function () {
    function AuthenticationServiceConfig() {
    }
    return AuthenticationServiceConfig;
}());

var SharePointServiceConfig = /** @class */ (function () {
    function SharePointServiceConfig() {
    }
    return SharePointServiceConfig;
}());

//#endregion
var SharePointService = /** @class */ (function () {
    //#endregion
    function SharePointService(config, http) {
        this.config = config;
        this.http = http;
    }
    //#region Utilities
    SharePointService.prototype.getListItems = function (list) {
        return this.http.post(this.config.sharePointApiUrl, list);
    };
    SharePointService.prototype.getListItemsSimple = function (list, view, site, limit) {
        return this.http.get(this.config.sharePointApiUrl + "/" + list + "/" + view + "/" + site + "/" + limit);
    };
    SharePointService.prototype.getPeople = function (storePeople) {
        var _this = this;
        // Do we already have people stored locally?
        if (this.people) {
            return of(this.people);
            // return Observable.of(this.people);
        }
        // Should we store people locally for subsequent calls?
        if (storePeople) {
            this.http.get(this.config.sharePointApiUrl + "/people")
                .subscribe(function (peeps) { return _this.people = peeps; });
        }
        return this.http.get(this.config.sharePointApiUrl + "/people");
    };
    SharePointService.prototype.getPhotos = function (storePhotos) {
        var _this = this;
        // Do we already have photos stored locally?
        if (this.photos) {
            return of(this.photos);
            // return Observable.of(this.photos);
        }
        var spList = {
            list: 'Employee Thumbnail Photos',
            view: 'All Pictures',
            site: 'http://cpsp1/DigitalDisplay',
            userName: this.config.userName,
            password: this.config.password
        };
        // Should we store photos locally for subsequent calls?
        if (storePhotos) {
            this.http.post(this.config.sharePointApiUrl, spList)
                .subscribe(function (photos) { return _this.photos = photos; });
        }
        return this.http.post(this.config.sharePointApiUrl, spList);
    };
    SharePointService.prototype.getCustomerVisits = function () {
        var list = {
            list: 'Customer Visits',
            view: 'All Events',
            userName: this.config.userName,
            password: this.config.password
        };
        return this.http.post(this.config.sharePointApiUrl, list);
    };
    SharePointService.ctorParameters = function () { return [
        { type: SharePointServiceConfig, decorators: [{ type: Optional }] },
        { type: HttpClient }
    ]; };
    SharePointService = __decorate([
        Injectable(),
        __param(0, Optional())
    ], SharePointService);
    return SharePointService;
}());

//#endregion
/**
 * Authenticate Active Directory user
 */
var AuthenticationService = /** @class */ (function () {
    //#endregion
    //#region Lifecycle
    /**
     * @ignore
     */
    function AuthenticationService(config, http, sharePointService) {
        this.http = http;
        this.sharePointService = sharePointService;
        this.authenticatedChanged = new EventEmitter();
        this.authenticatingChanged = new EventEmitter();
        /**
         * Flag set to true while the service is attempting to authenticate the user
         */
        this.authenticating = false;
        /**
         * Flag set to true when the user is successfully authenticated
         */
        this.authenticated = false;
        this.authenticationApiUrl = config.authenticationApiUrl;
        this.checkForExistingToken();
    }
    //#endregion
    //#region Utilities
    /**
     * Authenticate the user and store the token in Local Storage
     *
     * @param username AD sAMAccountName
     * @param password
     * @param adminGroup AD group that determines if authenticated user is considered an administrator of the app
     */
    AuthenticationService.prototype.login = function (username, password, adminGroup) {
        var _this = this;
        var today = new Date();
        var expiration = new Date().setFullYear(today.getFullYear() + 10);
        var request = {
            username: username,
            password: password,
            adminGroup: adminGroup,
            expirationDate: expiration // moment().add(10, 'years').toDate()
        };
        this.authenticating = true;
        this.authenticatingChanged.emit(this.authenticating);
        this.http.post(this.authenticationApiUrl, request)
            .subscribe(function (token) { return _this.validateUser(token); }, function (err) {
            _this.authenticating = false;
            _this.authenticatingChanged.emit(_this.authenticating);
        });
    };
    /**
     * Logout the user and delete the token from Local Storage
     */
    AuthenticationService.prototype.logout = function () {
        if (localStorage.getItem('token')) {
            localStorage.removeItem('token');
        }
        this.authenticatedUser = null;
        this.authenticated = false;
        this.authenticatedChanged.emit(false);
    };
    /**
     * @ignore
     */
    AuthenticationService.prototype.validateUser = function (token) {
        if (!token) {
            return;
        }
        var jwtHelper = new JwtHelperService();
        var decoded = jwtHelper.decodeToken(token);
        if (jwtHelper.isTokenExpired(token)) {
            this.logout();
            return;
        }
        this.authenticatedUser = {
            admin: decoded.role === 'Admin',
            displayName: decoded.displayName,
            accountName: decoded.winaccountname,
            distinguishedName: decoded.distinguishedName,
            employeeNumber: decoded.employeeNumber,
            memberOf: decoded.memberOf
        };
        localStorage.setItem('token', token);
        this.getPhoto();
        this.authenticated = true;
        this.authenticatedChanged.emit(this.authenticated);
        this.authenticating = false;
        this.authenticatingChanged.emit(this.authenticating);
    };
    /**
     * @ignore
     */
    AuthenticationService.prototype.getPhoto = function () {
        var _this = this;
        this.sharePointService.getPhotos()
            .subscribe(function (photos) {
            // The user may have been logged out by the time the photos came back
            if (!_this.authenticatedUser || !_this.authenticatedUser.employeeNumber) {
                return;
            }
            var photo = photos.find(function (pic) { return +pic.ows_EmployeeNumber === +_this.authenticatedUser.employeeNumber; });
            if (photo) {
                _this.authenticatedUser.photoUrl = photo.ows_EncodedAbsUrl;
            }
        });
    };
    /**
     * @ignore
     */
    AuthenticationService.prototype.checkForExistingToken = function () {
        if (localStorage.getItem('token')) {
            this.validateUser(localStorage.getItem('token'));
        }
    };
    AuthenticationService.ctorParameters = function () { return [
        { type: AuthenticationServiceConfig, decorators: [{ type: Optional }] },
        { type: HttpClient },
        { type: SharePointService }
    ]; };
    __decorate([
        Output()
    ], AuthenticationService.prototype, "authenticatedChanged", void 0);
    __decorate([
        Output()
    ], AuthenticationService.prototype, "authenticatingChanged", void 0);
    AuthenticationService = __decorate([
        Injectable(),
        __param(0, Optional())
    ], AuthenticationService);
    return AuthenticationService;
}());

var LoginFormComponent = /** @class */ (function () {
    function LoginFormComponent(dialogRef, sharePointService, authenticationService, data) {
        this.dialogRef = dialogRef;
        this.sharePointService = sharePointService;
        this.authenticationService = authenticationService;
        this.data = data;
        this.adminGroup = data.adminGroup;
    }
    LoginFormComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.authenticationService.authenticatedChanged
            .subscribe(function (authenticated) {
            if (authenticated) {
                _this.dialogRef.close();
            }
        });
    };
    LoginFormComponent.prototype.authenticate = function () {
        if (!this.sharePointService || !this.username || !this.password) {
            return;
        }
        this.authenticationService.login(this.username, this.password, this.adminGroup);
    };
    LoginFormComponent.ctorParameters = function () { return [
        { type: MatDialogRef },
        { type: SharePointService },
        { type: AuthenticationService },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
    ]; };
    LoginFormComponent = __decorate([
        Component({
            selector: 'cp-login-form',
            template: "<h2 mat-dialog-title>\n  <span *ngIf=\"!authenticationService.authenticating\">Login</span>\n  <span *ngIf=\"authenticationService.authenticating\">Authenticating...</span>\n</h2>\n\n<mat-dialog-content [class.loginError]=\"loginError\">\n  <div id=\"spinner\" *ngIf=\"authenticationService.authenticating\">\n    <mat-progress-spinner color=\"primary\" mode=\"indeterminate\"></mat-progress-spinner>\n  </div>\n\n  <div *ngIf=\"!authenticationService.authenticating\">\n    <div>\n      <mat-form-field>\n        <input matInput placeholder=\"Username\" [(ngModel)]=\"username\" name=\"username\" required (keyup.enter)=\"authenticate()\">\n      </mat-form-field>\n    </div>\n\n    <div>\n      <mat-form-field>\n        <input matInput type=\"password\" placeholder=\"Password\" [(ngModel)]=\"password\" name=\"password\" required (keyup.enter)=\"authenticate()\">\n      </mat-form-field>\n    </div>\n  </div>\n\n  <div *ngIf=\"!authenticationService.authenticating && loginError\" class=\"alert alert-danger\">\n    Bad username or password\n  </div>\n</mat-dialog-content>\n\n<mat-dialog-actions *ngIf=\"!authenticationService.authenticating\">\n  <button type=\"button\" mat-raised-button (click)=\"authenticate()\">OK</button>\n  <button type=\"button\" mat-button (click)=\"dialogRef.close()\">Cancel</button>\n</mat-dialog-actions>",
            styles: ["#spinner{width:100%;height:100%;display:flex;justify-content:center;align-items:center}mat-dialog-content{height:150px}mat-dialog-content.loginError{height:200px}"]
        }),
        __param(3, Inject(MAT_DIALOG_DATA))
    ], LoginFormComponent);
    return LoginFormComponent;
}());

var LoginComponent = /** @class */ (function () {
    function LoginComponent(dialog, authenticationService) {
        this.dialog = dialog;
        this.authenticationService = authenticationService;
    }
    LoginComponent.prototype.ngOnInit = function () {
    };
    LoginComponent.prototype.login = function () {
        this.dialog.open(LoginFormComponent, {
            data: { adminGroup: this.adminGroup }
        });
    };
    LoginComponent.prototype.confirmLogout = function () {
        var _this = this;
        var dialogRef = this.dialog.open(ConfirmationDialogComponent, {
            data: { message: "Are you sure you want to logout?" }
        });
        dialogRef.afterClosed().subscribe(function (result) {
            if (result) {
                _this.authenticationService.logout();
            }
        });
    };
    LoginComponent.ctorParameters = function () { return [
        { type: MatDialog },
        { type: AuthenticationService }
    ]; };
    __decorate([
        Input()
    ], LoginComponent.prototype, "adminGroup", void 0);
    LoginComponent = __decorate([
        Component({
            selector: 'cp-login',
            template: "<div id=\"user-id\">\n  <i id=\"unauthenticated-user-image\" *ngIf=\"!authenticationService.authenticated\"\n    class=\"fa fa-user-circle\"\n    [class.fa-spin]=\"authenticationService.authenticating\"\n    aria-hidden=\"true\"\n    matTooltip=\"Login\"\n    (click)=\"login()\"></i>\n\n  <img id=\"authenticated-user-image\"\n    *ngIf=\"authenticationService.authenticated && authenticationService.authenticatedUser.photoUrl\"\n    [src]=\"authenticationService.authenticatedUser.photoUrl\"\n    matTooltip=\"Logout\"\n    (click)=\"confirmLogout()\" />\n\n  <i id=\"authenticated-user-image\"\n    *ngIf=\"authenticationService.authenticated && !authenticationService.authenticatedUser.photoUrl\"\n    class=\"fa fa-user-circle\"\n    matTooltip=\"Logout\"\n    (click)=\"confirmLogout()\"></i>\n\n  <div id=\"user-name\" *ngIf=\"authenticationService.authenticated\">\n    {{ authenticationService.authenticatedUser.displayName }}\n  </div>\n</div>",
            styles: ["#user-id{display:flex;height:2em;padding:.3em;font-family:Verdana,Geneva,Tahoma,sans-serif}.fa{font-size:2em}img{border-radius:100%;width:2em;height:2em}#user-id>div{display:flex;align-items:center;height:100%;margin-left:.75em;font-size:1.15em}"]
        })
    ], LoginComponent);
    return LoginComponent;
}());

//#endregion
/**
 * Provides a component and a service that allows you to perform Active/Directory authentication
 */
var AuthenticationModule = /** @class */ (function () {
    function AuthenticationModule(parentModule) {
        if (parentModule) {
            throw new Error('AuthenticationModule is already loaded. Import it in the AppModule only');
        }
    }
    AuthenticationModule_1 = AuthenticationModule;
    AuthenticationModule.forRoot = function (authenticationConfig) {
        return {
            ngModule: AuthenticationModule_1,
            providers: [
                AuthenticationService,
                { provide: AuthenticationServiceConfig, useValue: authenticationConfig }
            ]
        };
    };
    var AuthenticationModule_1;
    AuthenticationModule.ctorParameters = function () { return [
        { type: AuthenticationModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
    ]; };
    AuthenticationModule = AuthenticationModule_1 = __decorate([
        NgModule({
            imports: [
                CommonModule,
                FormsModule,
                MatButtonModule,
                MatCheckboxModule,
                MatDialogModule,
                MatInputModule,
                MatProgressBarModule,
                MatProgressSpinnerModule,
                MatTooltipModule,
                MatSelectModule,
                DialogModule
            ],
            declarations: [
                LoginComponent,
                LoginFormComponent
            ],
            exports: [
                LoginComponent,
                LoginFormComponent
            ],
            providers: [],
            entryComponents: [
                LoginFormComponent
            ]
        }),
        __param(0, Optional()), __param(0, SkipSelf())
    ], AuthenticationModule);
    return AuthenticationModule;
}());

var EmailServiceConfig = /** @class */ (function () {
    function EmailServiceConfig() {
    }
    return EmailServiceConfig;
}());

//#endregion
var EmailService = /** @class */ (function () {
    function EmailService(config, http) {
        this.http = http;
        this.emailServiceConfig = config;
    }
    EmailService.prototype.send = function (email) {
        var dto = {
            server: this.emailServiceConfig.server,
            smtpPort: this.emailServiceConfig.smtpPort,
            sender: this.emailServiceConfig.sender,
            subject: email.subject,
            content: email.content,
            recipients: email.recipients
        };
        return this.http.post(this.emailServiceConfig.emailApiUrl, dto);
    };
    EmailService.ctorParameters = function () { return [
        { type: EmailServiceConfig, decorators: [{ type: Optional }] },
        { type: HttpClient }
    ]; };
    EmailService = __decorate([
        Injectable(),
        __param(0, Optional())
    ], EmailService);
    return EmailService;
}());

//#endregion
var EmailModule = /** @class */ (function () {
    function EmailModule(parentModule) {
        if (parentModule) {
            throw new Error('EmailModule is already loaded. Import it in the AppModule only');
        }
    }
    EmailModule_1 = EmailModule;
    EmailModule.forRoot = function (emailConfig) {
        return {
            ngModule: EmailModule_1,
            providers: [
                EmailService,
                { provide: EmailServiceConfig, useValue: emailConfig }
            ]
        };
    };
    var EmailModule_1;
    EmailModule.ctorParameters = function () { return [
        { type: EmailModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
    ]; };
    EmailModule = EmailModule_1 = __decorate([
        NgModule({
            imports: [CommonModule],
            declarations: [],
            exports: []
        }),
        __param(0, Optional()), __param(0, SkipSelf())
    ], EmailModule);
    return EmailModule;
}());

var EmployeeServiceConfig = /** @class */ (function () {
    function EmployeeServiceConfig() {
    }
    return EmployeeServiceConfig;
}());

//#endregion
var EmployeeService = /** @class */ (function () {
    //#endregion
    //#region Lifecycle
    function EmployeeService(config, http) {
        this.http = http;
        this.employeeApiUrl = config.employeeApiUrl;
    }
    //#endregion
    //#region Utilities
    EmployeeService.prototype.getEmployees = function (storeEmployees, includeDisabled) {
        var _this = this;
        if (storeEmployees === void 0) { storeEmployees = false; }
        if (includeDisabled === void 0) { includeDisabled = false; }
        // Do we already have employees stored locally?
        if (this.employees) {
            return of(this.employees);
            // return Observable.of(this.employees);
        }
        // Should we store employees locally for subsequent calls?
        if (storeEmployees) {
            this.http.get(this.employeeApiUrl + "/false/" + includeDisabled)
                .subscribe(function (emps) { return _this.employees = emps; });
        }
        return this.http.get(this.employeeApiUrl + "/false/" + includeDisabled);
    };
    EmployeeService.prototype.getEmployee = function (sAMAccountName) {
        return this.http.get(this.employeeApiUrl + "/name/" + sAMAccountName);
    };
    EmployeeService.ctorParameters = function () { return [
        { type: EmployeeServiceConfig, decorators: [{ type: Optional }] },
        { type: HttpClient }
    ]; };
    EmployeeService = __decorate([
        Injectable(),
        __param(0, Optional())
    ], EmployeeService);
    return EmployeeService;
}());

var DepartmentsPipe = /** @class */ (function () {
    function DepartmentsPipe() {
    }
    DepartmentsPipe.prototype.transform = function (employees, args) {
        var departments = [];
        employees
            .filter(function (emp) { return emp.department; })
            .forEach(function (emp) {
            if (departments.indexOf(emp.department) === -1) {
                departments.push(emp.department);
            }
        });
        return departments.sort();
    };
    DepartmentsPipe = __decorate([
        Pipe({
            name: 'departments'
        })
    ], DepartmentsPipe);
    return DepartmentsPipe;
}());

var EmployeeByDnPipe = /** @class */ (function () {
    function EmployeeByDnPipe() {
    }
    EmployeeByDnPipe.prototype.transform = function (employees, dn) {
        return employees
            .find(function (emp) { return emp.distinguishedName.toLowerCase() === dn.toLowerCase(); });
    };
    EmployeeByDnPipe = __decorate([
        Pipe({
            name: 'employeeByDn'
        })
    ], EmployeeByDnPipe);
    return EmployeeByDnPipe;
}());

var EmployeePhotoUrlPipe = /** @class */ (function () {
    function EmployeePhotoUrlPipe() {
    }
    EmployeePhotoUrlPipe.prototype.transform = function (employee, photos) {
        if (!photos) {
            return null;
        }
        // Try to match by employeeNumber, accountName, or title
        var photo = photos
            .find(function (pic) {
            return (pic.ows_EmployeeNumber && employee.employeeNumber && +pic.ows_EmployeeNumber === +employee.employeeNumber) ||
                (pic.ows_AccountName && pic.ows_AccountName.toLowerCase() === employee.sAMAccountName.toLowerCase()) ||
                (pic.ows_Title && pic.ows_Title.toLowerCase() === employee.displayName.toLowerCase());
        });
        if (!photo) {
            console.log("No photo match for " + employee.displayName);
        }
        return photo ? photo.ows_EncodedAbsUrl : null;
    };
    EmployeePhotoUrlPipe = __decorate([
        Pipe({
            name: 'employeePhotoUrl'
        })
    ], EmployeePhotoUrlPipe);
    return EmployeePhotoUrlPipe;
}());

var EmployeesWithPropertyValuePipe = /** @class */ (function () {
    function EmployeesWithPropertyValuePipe() {
    }
    EmployeesWithPropertyValuePipe.prototype.transform = function (employees, propertyName, propertyValue) {
        return employees
            .filter(function (emp) { return emp[propertyName] && emp[propertyName] === propertyValue; });
    };
    EmployeesWithPropertyValuePipe = __decorate([
        Pipe({
            name: 'employeesWithPropertyValue'
        })
    ], EmployeesWithPropertyValuePipe);
    return EmployeesWithPropertyValuePipe;
}());

var FilterEmployeesPipe = /** @class */ (function () {
    function FilterEmployeesPipe() {
    }
    FilterEmployeesPipe.prototype.transform = function (employees, filter) {
        return filter ?
            employees
                .filter(function (emp) {
                return emp.displayName.toLowerCase().indexOf(filter.toLowerCase()) !== -1 ||
                    (emp.department && emp.department.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                    (emp.title && emp.title.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                    emp.sAMAccountName.toLowerCase().indexOf(filter.toLowerCase()) !== -1;
            }) :
            employees;
    };
    FilterEmployeesPipe = __decorate([
        Pipe({
            name: 'filterEmployees'
        })
    ], FilterEmployeesPipe);
    return FilterEmployeesPipe;
}());

var IsMemberOfPipe = /** @class */ (function () {
    function IsMemberOfPipe() {
    }
    IsMemberOfPipe.prototype.transform = function (employee, groupName) {
        return employee.memberOf &&
            (employee.memberOf.find(function (m) { return m.toLowerCase().indexOf(groupName.toLowerCase()) !== -1; }) !== undefined);
    };
    IsMemberOfPipe = __decorate([
        Pipe({
            name: 'isMemberOf'
        })
    ], IsMemberOfPipe);
    return IsMemberOfPipe;
}());

var SortEmployeesPipe = /** @class */ (function () {
    function SortEmployeesPipe() {
    }
    SortEmployeesPipe.prototype.transform = function (employees, sortBy, dataType, reverse) {
        return this.getSorted(employees, sortBy ? sortBy : 'displayName', dataType ? dataType : 'string', reverse ? reverse : false);
    };
    SortEmployeesPipe.prototype.getSorted = function (employees, sortBy, dataType, reverse) {
        var sorted = employees
            .sort(function (a, b) {
            var valA, valB;
            switch (dataType.toLowerCase()) {
                case 'string':
                    valA = a[sortBy] ? a[sortBy].toString().toLowerCase() : null;
                    valB = b[sortBy] ? b[sortBy].toString().toLowerCase() : null;
                    break;
                case 'number':
                    valA = a[sortBy] ? +a[sortBy] : null;
                    valB = b[sortBy] ? +b[sortBy] : null;
                    break;
                case 'date':
                    valA = a[sortBy] ? a[sortBy] : null;
                    valB = b[sortBy] ? b[sortBy] : null;
                    break;
            }
            if (valA < valB) {
                return -1;
            }
            if (valA > valB) {
                return 1;
            }
            return 0;
        });
        return reverse ? sorted.reverse() : sorted;
    };
    SortEmployeesPipe = __decorate([
        Pipe({
            name: 'sortEmployees'
        })
    ], SortEmployeesPipe);
    return SortEmployeesPipe;
}());

//#endregion
var EmployeeModule = /** @class */ (function () {
    function EmployeeModule(parentModule) {
        if (parentModule) {
            throw new Error('EmployeeModule is already loaded. Import it in the AppModule only');
        }
    }
    EmployeeModule_1 = EmployeeModule;
    EmployeeModule.forRoot = function (employeeConfig) {
        return {
            ngModule: EmployeeModule_1,
            providers: [
                EmployeeService,
                { provide: EmployeeServiceConfig, useValue: employeeConfig }
            ]
        };
    };
    var EmployeeModule_1;
    EmployeeModule.ctorParameters = function () { return [
        { type: EmployeeModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
    ]; };
    EmployeeModule = EmployeeModule_1 = __decorate([
        NgModule({
            imports: [CommonModule],
            declarations: [
                DepartmentsPipe,
                EmployeeByDnPipe,
                EmployeesWithPropertyValuePipe,
                FilterEmployeesPipe,
                IsMemberOfPipe,
                EmployeePhotoUrlPipe,
                SortEmployeesPipe
            ],
            exports: [
                DepartmentsPipe,
                EmployeeByDnPipe,
                EmployeesWithPropertyValuePipe,
                FilterEmployeesPipe,
                IsMemberOfPipe,
                EmployeePhotoUrlPipe,
                SortEmployeesPipe
            ]
        }),
        __param(0, Optional()), __param(0, SkipSelf())
    ], EmployeeModule);
    return EmployeeModule;
}());

var SharePointPhotoUrlPipe = /** @class */ (function () {
    function SharePointPhotoUrlPipe() {
    }
    SharePointPhotoUrlPipe.prototype.transform = function (photo) {
        return photo.ows_EncodedAbsUrl;
    };
    SharePointPhotoUrlPipe = __decorate([
        Pipe({
            name: 'sharePointPhotoUrl'
        })
    ], SharePointPhotoUrlPipe);
    return SharePointPhotoUrlPipe;
}());

var SharePointUrlPipe = /** @class */ (function () {
    function SharePointUrlPipe() {
    }
    SharePointUrlPipe.prototype.transform = function (url) {
        return url !== null ? url.split(',')[0] : null;
    };
    SharePointUrlPipe = __decorate([
        Pipe({
            name: 'sharePointUrl'
        })
    ], SharePointUrlPipe);
    return SharePointUrlPipe;
}());

//#endregion
var SharePointModule = /** @class */ (function () {
    function SharePointModule(parentModule) {
        if (parentModule) {
            throw new Error('SharePointModule is already loaded. Import it in the AppModule only');
        }
    }
    SharePointModule_1 = SharePointModule;
    SharePointModule.forRoot = function (sharePointConfig) {
        return {
            ngModule: SharePointModule_1,
            providers: [
                SharePointService,
                { provide: SharePointServiceConfig, useValue: sharePointConfig }
            ]
        };
    };
    var SharePointModule_1;
    SharePointModule.ctorParameters = function () { return [
        { type: SharePointModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
    ]; };
    SharePointModule = SharePointModule_1 = __decorate([
        NgModule({
            imports: [
                CommonModule
            ],
            declarations: [
                SharePointPhotoUrlPipe,
                SharePointUrlPipe
            ],
            exports: [
                SharePointPhotoUrlPipe,
                SharePointUrlPipe
            ]
        }),
        __param(0, Optional()), __param(0, SkipSelf())
    ], SharePointModule);
    return SharePointModule;
}());

var UploadServiceConfig = /** @class */ (function () {
    function UploadServiceConfig() {
    }
    return UploadServiceConfig;
}());

// https://malcoded.com/posts/angular-file-upload-component-with-express
var UploadService = /** @class */ (function () {
    function UploadService(http, config) {
        this.http = http;
        this.uploadApiUrl = config.uploadApiUrl;
        this.uploadPath = config.uploadPath || '';
        this.dbAppId = config.dbAppId || '';
        this.externalReferenceId = config.externalReferenceId || '';
        this.comment = config.comment || '';
        // UI configuration
        this.uploadButtonText = config.uploadButtonText;
        this.uploadDialogTitle = config.uploadDialogTitle;
        this.uploadDialogAddFilesButtonText = config.uploadDialogAddFilesButtonText;
        this.uploadDialogCancelButtonText = config.uploadDialogCancelButtonText;
        this.uploadDialogUploadButtonText = config.uploadDialogUploadButtonText;
        this.uploadDialogFinishButtonText = config.uploadDialogFinishButtonText;
    }
    UploadService.prototype.upload = function (files) {
        var _this = this;
        // this will be the our resulting map
        var status = {};
        files.forEach(function (file) {
            // create a new multipart-form for every file
            var formData = new FormData();
            formData.append('file', file, file.name);
            // create a http-post request and pass the form
            // tell it to report the upload progress
            // A 'Destination' header is used to optionally configure the file upload destination (filesystem)
            // A 'DbAppId' header is used to configure the unique identifier of database uploads
            var req = new HttpRequest('POST', _this.uploadApiUrl, formData, {
                reportProgress: true,
                responseType: 'blob',
                headers: new HttpHeaders()
                    .set('Destination', _this.uploadPath)
                    .set('DbAppId', _this.dbAppId)
                    .set('ExternalReferenceId', _this.externalReferenceId)
                    .set('Comment', _this.comment)
                /*headers: this.uploadPath ?
                  new HttpHeaders({ 'Destination': this.uploadPath }) :
                  this.dbAppId ?
                    new HttpHeaders({ 'DbAppId': this.dbAppId }) :
                    null*/
            });
            // create a new progress-subject for every file
            var progress = new Subject();
            // send the http-request and subscribe for progress-updates
            _this.http.request(req).subscribe(function (event) {
                if (event.type === HttpEventType.UploadProgress) {
                    // calculate the progress percentage
                    var percentDone = Math.round(100 * event.loaded / event.total);
                    // pass the percentage into the progress-stream
                    progress.next(percentDone);
                }
                else if (event instanceof HttpResponse) {
                    // Close the progress-stream if we get an answer form the API
                    // The upload is complete
                    progress.complete();
                }
            });
            // Save every progress-observable in a map of all observables
            status[file.name] = {
                progress: progress.asObservable()
            };
        });
        // return the map of progress.observables
        return status;
    };
    UploadService.prototype.exists = function (fileName) {
        var query = this.uploadApiUrl.toLowerCase().indexOf('filesystem') === -1 ?
            { name: fileName, dbAppId: this.dbAppId } :
            { name: fileName, destination: this.uploadPath };
        return this.http.post(this.uploadApiUrl + "/exists", query);
    };
    UploadService.prototype.download = function (request) {
        return this.http.post(this.uploadApiUrl + "/stream", request, { responseType: 'blob' });
    };
    UploadService.prototype.getUploadInfo = function (request) {
        return this.http.post(this.uploadApiUrl + "/info", request);
    };
    UploadService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: UploadServiceConfig, decorators: [{ type: Optional }] }
    ]; };
    UploadService = __decorate([
        Injectable(),
        __param(1, Optional())
    ], UploadService);
    return UploadService;
}());

var UploadDialogComponent = /** @class */ (function () {
    function UploadDialogComponent(dialogRef, uploadService) {
        this.dialogRef = dialogRef;
        this.uploadService = uploadService;
        this.files = new Set();
        this.canBeClosed = true;
        this.showCancelButton = true;
        this.uploading = false;
        this.uploadSuccessful = false;
    }
    UploadDialogComponent.prototype.ngOnInit = function () {
        this.uploadDialogTitle = this.uploadService.uploadDialogTitle ?
            this.uploadService.uploadDialogTitle :
            'Upload Files';
        this.uploadDialogAddFilesButtonText = this.uploadService.uploadDialogAddFilesButtonText ?
            this.uploadService.uploadDialogAddFilesButtonText :
            'Add Files';
        this.uploadDialogCancelButtonText = this.uploadService.uploadDialogCancelButtonText ?
            this.uploadService.uploadDialogCancelButtonText :
            'Cancel';
        this.uploadDialogUploadButtonText = this.uploadService.uploadDialogUploadButtonText ?
            this.uploadService.uploadDialogUploadButtonText :
            'Upload';
        this.uploadDialogFinishButtonText = this.uploadService.uploadDialogFinishButtonText ?
            this.uploadService.uploadDialogFinishButtonText :
            'Finish';
        this.primaryButtonText = this.uploadDialogUploadButtonText;
    };
    UploadDialogComponent.prototype.addFiles = function () {
        this.file.nativeElement.click();
    };
    UploadDialogComponent.prototype.onFilesAdded = function () {
        var _this = this;
        var files = this.file.nativeElement.files;
        var _loop_1 = function (key) {
            if (!isNaN(parseInt(key))) {
                // See if the file already exists
                this_1.uploadService.exists(files[key].name)
                    .subscribe(function (exists) {
                    if (exists) {
                        _this.existingFileConflict = files[key].name;
                    }
                    if (!exists) {
                        _this.files.add(files[key]);
                    }
                });
            }
        };
        var this_1 = this;
        for (var key in files) {
            _loop_1(key);
        }
    };
    UploadDialogComponent.prototype.closeDialog = function () {
        var _this = this;
        // if everything was uploaded already, just close the dialog
        if (this.uploadSuccessful) {
            return this.dialogRef.close();
        }
        // set the component state to "uploading"
        this.uploading = true;
        // start the upload and save the progress map
        this.progress = this.uploadService.upload(this.files);
        // convert the progress map into an array
        var allProgressObservables = [];
        for (var key in this.progress) {
            allProgressObservables.push(this.progress[key].progress);
        }
        // Adjust the state variables
        // The OK-button should have the text "Finish" now
        this.primaryButtonText = this.uploadDialogFinishButtonText;
        // The dialog should not be closed while uploading
        this.canBeClosed = false;
        this.dialogRef.disableClose = true;
        // Hide the cancel-button
        this.showCancelButton = false;
        // When all progress-observables are completed...
        forkJoin(allProgressObservables).subscribe(function (end) {
            // ... the dialog can be closed again...
            _this.canBeClosed = true;
            _this.dialogRef.disableClose = false;
            // ... the upload was successful...
            _this.uploadSuccessful = true;
            // ... and the component is no longer uploading
            _this.uploading = false;
        });
    };
    UploadDialogComponent.ctorParameters = function () { return [
        { type: MatDialogRef },
        { type: UploadService }
    ]; };
    __decorate([
        ViewChild('file', { static: true })
    ], UploadDialogComponent.prototype, "file", void 0);
    UploadDialogComponent = __decorate([
        Component({
            selector: 'cp-upload-dialog',
            template: "<input type=\"file\" #file style=\"display: none\" (change)=\"onFilesAdded()\" multiple />\r\n\r\n<div mat-dialog-title id=\"title\">\r\n  <div>{{ uploadDialogTitle }}</div>\r\n  <button [disabled]=\"uploading || uploadSuccessful\" mat-raised-button color=\"primary\" class=\"add-files-btn\" (click)=\"addFiles()\">\r\n    {{ uploadDialogAddFilesButtonText }}\r\n  </button>\r\n</div>\r\n\r\n<div id=\"conflict\" *ngIf=\"existingFileConflict\">\r\n  {{ existingFileConflict }} already exists on the server and cannot be overwritten\r\n</div>\r\n\r\n<mat-dialog-content>\r\n  <mat-list>\r\n    <mat-list-item *ngFor=\"let file of files\">\r\n      <h4 mat-line>{{file.name}}</h4>\r\n      <mat-progress-bar *ngIf=\"progress\" mode=\"determinate\" [value]=\"progress[file.name].progress | async\"></mat-progress-bar>\r\n    </mat-list-item>\r\n  </mat-list>\r\n</mat-dialog-content>\r\n\r\n<mat-dialog-actions id=\"actions\">\r\n  <button *ngIf=\"showCancelButton\" mat-button mat-dialog-close>{{ uploadDialogCancelButtonText }}</button>\r\n  <button *ngIf=\"files.size > 0\" mat-raised-button color=\"primary\" [disabled]=\"!canBeClosed\" (click)=\"closeDialog()\">{{ primaryButtonText }}</button>\r\n</mat-dialog-actions>\r\n",
            styles: ["#title{display:flex;justify-content:space-between}#actions{display:flex;justify-content:flex-end}#conflict{font-size:.8em;color:red;margin-top:.5em}"]
        })
    ], UploadDialogComponent);
    return UploadDialogComponent;
}());

var UploadComponent = /** @class */ (function () {
    function UploadComponent(dialog, uploadService) {
        this.dialog = dialog;
        this.uploadService = uploadService;
        this.dialogClosed = new EventEmitter();
    }
    UploadComponent.prototype.ngOnInit = function () {
        this.uploadButtonText = this.uploadService.uploadButtonText ?
            this.uploadService.uploadButtonText :
            'Upload';
    };
    UploadComponent.prototype.openUploadDialog = function () {
        var _this = this;
        this.dialog.open(UploadDialogComponent, { width: '50%' })
            .afterClosed().subscribe(function () { return _this.dialogClosed.emit(); });
    };
    UploadComponent.ctorParameters = function () { return [
        { type: MatDialog },
        { type: UploadService }
    ]; };
    __decorate([
        Output()
    ], UploadComponent.prototype, "dialogClosed", void 0);
    UploadComponent = __decorate([
        Component({
            selector: 'cp-upload',
            template: '<button mat-raised-button (click)="openUploadDialog()">{{ uploadButtonText }}</button>'
        })
    ], UploadComponent);
    return UploadComponent;
}());

//#endregion
var UploadModule = /** @class */ (function () {
    function UploadModule(parentModule) {
        if (parentModule) {
            throw new Error('UploadModule is already loaded. Import it in the AppModule only');
        }
    }
    UploadModule_1 = UploadModule;
    UploadModule.forRoot = function (uploadConfig) {
        return {
            ngModule: UploadModule_1,
            providers: [
                UploadService,
                { provide: UploadServiceConfig, useValue: uploadConfig }
            ]
        };
    };
    var UploadModule_1;
    UploadModule.ctorParameters = function () { return [
        { type: UploadModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
    ]; };
    UploadModule = UploadModule_1 = __decorate([
        NgModule({
            imports: [
                CommonModule,
                BrowserAnimationsModule,
                HttpClientModule,
                MatButtonModule,
                MatDialogModule,
                MatListModule,
                MatProgressBarModule
            ],
            declarations: [
                UploadComponent,
                UploadDialogComponent
            ],
            exports: [
                UploadComponent,
                UploadDialogComponent
            ],
            entryComponents: [
                UploadDialogComponent
            ]
        }),
        __param(0, Optional()), __param(0, SkipSelf())
    ], UploadModule);
    return UploadModule;
}());

// This pipe whitelists URLs so that they aren't prefixed with 'unsafe:' when they render in the DOM
var SafeUrlPipe = /** @class */ (function () {
    function SafeUrlPipe(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    SafeUrlPipe.prototype.transform = function (value) {
        return this.domSanitizer.bypassSecurityTrustUrl(value);
    };
    SafeUrlPipe.ctorParameters = function () { return [
        { type: DomSanitizer }
    ]; };
    SafeUrlPipe = __decorate([
        Pipe({
            name: 'safeUrl'
        })
    ], SafeUrlPipe);
    return SafeUrlPipe;
}());

var UriSchemePipe = /** @class */ (function () {
    function UriSchemePipe() {
    }
    // https://docs.microsoft.com/en-us/office/client-developer/office-uri-schemes
    UriSchemePipe.prototype.transform = function (value) {
        if (!localStorage.getItem('useUriScheme')) {
            return value;
        }
        var urlSplit = value.split('.');
        var extension = urlSplit[urlSplit.length - 1];
        if (!extension) {
            return value;
        }
        var command = this.command(extension);
        var app = this.app(extension);
        return "ms-" + app + ":" + command + "|u|" + value;
    };
    UriSchemePipe.prototype.app = function (extension) {
        switch (extension.toLowerCase()) {
            // documents
            case 'doc':
            case 'docx':
            case 'docm':
            case 'docb':
            case 'dot':
            case 'dotx':
            case 'dotm': // templates
                return 'word';
            case 'xls':
            case 'xlsx':
            case 'xlm':
            case 'xlsm':
            case 'xlsb':
            case 'xlw':
            case 'xlt':
            case 'xltx':
            case 'xltm': // templates
                return 'excel';
            case 'ppt':
            case 'pptx':
            case 'pps':
            case 'ppsx':
            case 'pptm':
            case 'ppsm':
            case 'sldx':
            case 'sldm':
            case 'pot':
            case 'potx':
            case 'potm': // templates
                return 'powerpoint';
            case 'vsd':
            case 'vsdx':
            case 'vst':
            case 'vstx': // templates
                return 'visio';
            case 'mdb':
            case 'accdb':
            case 'accde':
            case 'accdr':
            case 'accdt': // templates
                return 'access';
            case 'mpp':
            case 'mppx':
            case 'mpt': // templates
                return 'project';
            case 'pub':
                return 'publisher';
            case 'xsn':
                return 'infopath';
        }
    };
    UriSchemePipe.prototype.command = function (extension) {
        switch (extension.toLowerCase()) {
            case 'dot':
            case 'dotx':
            case 'dotm':
            case 'xlt':
            case 'xltx':
            case 'xltm':
            case 'pot':
            case 'potx':
            case 'potm':
            case 'vst':
            case 'vstx':
            case 'accdt':
            case 'mpt':
                return 'nft'; // new from template
            default:
                var openMode = 'v'; // for view, or 'e' or edit
                return "of" + openMode; // default: open file as view/edit
        }
    };
    UriSchemePipe = __decorate([
        Pipe({
            name: 'uriScheme',
            pure: false
        })
    ], UriSchemePipe);
    return UriSchemePipe;
}());

//#endregion
var UrlModule = /** @class */ (function () {
    function UrlModule() {
    }
    UrlModule = __decorate([
        NgModule({
            imports: [
                CommonModule
            ],
            declarations: [
                SafeUrlPipe,
                UriSchemePipe
            ],
            exports: [
                SafeUrlPipe,
                UriSchemePipe
            ],
            entryComponents: []
        })
    ], UrlModule);
    return UrlModule;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { AuthenticationModule, AuthenticationService, AuthenticationServiceConfig, ConfirmationDialogComponent, ConfirmationDialogMode, DepartmentsPipe, DialogModule, EmailModule, EmailService, EmailServiceConfig, EmployeeByDnPipe, EmployeeModule, EmployeePhotoUrlPipe, EmployeeService, EmployeeServiceConfig, EmployeesWithPropertyValuePipe, FilterEmployeesPipe, InputDialogComponent, IsMemberOfPipe, LoginComponent, LoginFormComponent, MessageDialogComponent, SafeUrlPipe, SharePointModule, SharePointPhotoUrlPipe, SharePointService, SharePointServiceConfig, SharePointUrlPipe, SortEmployeesPipe, UploadComponent, UploadDialogComponent, UploadModule, UploadService, UploadServiceConfig, UriSchemePipe, UrlModule, DialogComponent as ɵa };
//# sourceMappingURL=cleavelandprice-ngx-lib.js.map
